%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%   This file is part of chemotaxis pathway designer                    % 
%                                                                       % 
%   Copyright (C) Junjie Luo     jjluo54@163.com                        % 
%                 Jun Wang       wj-cn@163.com                          % 
%   All rights reserved.                                                % 
%                                                                       % 
%   $File: Parameter_test_single_core.m$     $Revision:  1$             %   
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function Parameter_test(number);
% number : The number of the parameter in the parameter list.
% Return value :
%   bact_posi :   The trace of the bacteria 
%   bact_L :      The local ligand concentration of the bacteria
%   L_mean :      The average local ligand concentration of bacteria population 
%                    in the last 100 time points
%   file_name :   The file name to be saved as
%   randseed :    The random seed
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

tic        % Start the timer

%Set the random seed
randseed = sum(100 * clock);            
rand('state', randseed);

%Set parameter list
%The four parameters in each line is 
%       amplification,  order,  field,   initial point
para_list = [{8} ,       {2},  {'line'} ,  {[1.4 0]};...
            {32},        {2},  {'line'} ,  {[1.4 0]};...
            {16},        {2},  {'line'} ,  {[3.5 0]};...
            {16},        {2},  {'point'},  {[3.5 0]};...
            {8} ,        {2},  {'line2'},  {[1.4 0]};...
            {16},        {2},  {'point'},  {[1.4 0]};...
            {16},        {4},  {'line'} ,  {[1.4 0]};...
            {32},        {4},  {'line'} ,  {[1.4 0]};...
          ];

bacteria_num=1;%00;             % The number of bacteria 
turn_1_list=[0.3 0.2 0.1 0.05 0.03 0.02 0.01 0.005 0.003 0.002 0.001];
                                % Down cutoff frequency
turn_2_list=[100 50 30 20 10 5 3 2 1 0.5 0.3];
                                % Up cutoff frequency

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

para_i = number;
   
if cell2mat(para_list(para_i,4))==[1.4 0]
    initial_name='middle';
else
    initial_name='low';
end

file_name=[mat2str(cell2mat(para_list(para_i,1))),'_',...
          mat2str(cell2mat(para_list(para_i,2))),'_',...
          cell2mat(para_list(para_i,3)),'_',...
          initial_name];

for turn_1_i=1:size(turn_1_list,2)
    for turn_2_i=1:size(turn_2_list,2)
        for bact_i=1:bacteria_num
            bact_posi(:,:,bact_i,turn_1_i,turn_2_i)=...
                bacterium_parameter_test(turn_1_list(turn_1_i),turn_2_list(turn_2_i),...
                                         cell2mat(para_list(para_i,1)),...%amplification,
                                         cell2mat(para_list(para_i,2)),...%order,
                                         cell2mat(para_list(para_i,3)),...%field,
                                         cell2mat(para_list(para_i,4)));%initial point
            for time_point=1:100
                bact_L(time_point,bact_i,turn_1_i,turn_2_i)=...
                     L(bact_posi(time_point,:,bact_i,turn_1_i,turn_2_i),cell2mat(para_list(para_i,3)));
            end
        end
    end
end
L_mean = permute(mean(mean(bact_L),2),[3 4 1 2]);

save(file_name, 'bact_posi', 'bact_L', 'L_mean', 'randseed');

toc      % Close the timer and output the total running time