%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%   This file is part of chemotaxis pathway designer                    % 
%                                                                       % 
%   Copyright (C) Junjie Luo     jjluo54@163.com                        % 
%                 Jun Wang       wj-cn@163.com                          % 
%   All rights reserved.                                                % 
%                                                                       % 
%   $File: Picture.m$     $Revision:  1$                                %   
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clc,clear,close all
%set parameter list
%amplification, order, field, initial point
para_list=[{8} ,{2},{'line'} ,{[1.4 0]};...
           {32},{2},{'line'} ,{[1.4 0]};...
           {16},{2},{'line'} ,{[3.5 0]};...
           {16},{2},{'point'},{[3.5 0]};...
           {8} ,{2},{'line2'},{[1.4 0]};...
           {16},{2},{'point'},{[1.4 0]};...
           {16},{4},{'line'} ,{[1.4 0]};...
           {32},{4},{'line'} ,{[1.4 0]};...
          ];

bacteria_num = 100;
turn_1_list = [0.3 0.2 0.1 0.05 0.03 0.02 0.01 0.005 0.003 0.002 0.001];
turn_2_list = [100 50 30 20 10 5 3 2 1 0.5 0.3];

for para_i=1 : size(para_list,1)%1
    
    if cell2mat(para_list(para_i,4))==[1.4 0]
        initial_name='middle';
    else
        initial_name='low';
    end
    
    file_name=[mat2str(cell2mat(para_list(para_i,1))),'_',...
              mat2str(cell2mat(para_list(para_i,2))),'_',...
              cell2mat(para_list(para_i,3)),'_',...
              initial_name];
    

    load(['supfig3data\',file_name,'_1']);
    L_inter=L_mean;
    load(['supfig3data\',file_name,'_2']);
    L_mean=(L_inter+L_mean)/2;

%% Create figure
    picname=file_name;
figure1 = figure(...
  'FileName',picname,...
  'PaperPosition',[-3.04 5.658 27.07 18.35],...
  'PaperSize',[20.98 29.68]);
 
%% Create axes
axes1 = axes(...
  'FontSize',18,...
  'XMinorGrid','on',...
  'XMinorTick','on',...
  'XScale','log',...
  'XTick',[1 10 100],...
  'YMinorGrid','on',...
  'YMinorTick','on',...
  'YScale','log',...
  'YTick',[0.001 0.01 0.1],...
  'Parent',figure1);

if para_i==3 | para_i==4 | para_i==5
    axis(axes1,[0.3 100 0.001 0.3 0.3 2]);
else
    axis(axes1,[0.3 100 0.001 0.3 1.2 2]);
end
%title(axes1,'Final Average Ligand Concentration');
xlabel(axes1,'\omega_2 (Hz)','fontsize',20);
ylabel(axes1,'\omega_1 (Hz)','fontsize',20);
zlabel(axes1,'[L]_{mean} (\muM)','fontsize',20);
view(axes1,[-37.5 30]);
grid(axes1,'on');
hold(axes1,'all');
 
%% Create mesh
C = meshc(turn_2_list,turn_1_list,L_mean,'Parent',axes1);
surface(turn_2_list,turn_1_list,L_mean,'FaceColor','interp','EdgeColor','interp')
%clabel(C,[1.3:0.1:2],'fontsize',12);

%% Create colorbar
colorbar1 = colorbar('peer',...
  axes1,'EastOutside',...
  'Box','on',...
  'XLim',[-0.5 1.5],...
  'fontsize',18);
pause,
%% Save Picture
    %hgsave(figure1,picname),

    saveas(figure1,picname,'jpg')%%%%%
    saveas(figure1,picname,'eps')
    %saveas(figure1,picname,'pdf')
    
end