%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%   This file is part of chemotaxis pathway designer                    % 
%                                                                       % 
%   Copyright (C) Junjie Luo     jjluo54@163.com                        % 
%                 Jun Wang       wj-cn@163.com                          % 
%   All rights reserved.                                                % 
%                                                                       % 
%   $File: avicreate_segment.m$     $Revision:  1$                       %   
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

clc,
clear,
close all

% Set the file name of the data
file_name = 'bact_pos_dir'

% Load the data
load(file_name);

% Set the moving steps of the bacteria in the movie
STEPS = size(bact_xd, 1);

% Create the avi file with fps = ** 
aviobj = avifile('bacteria_movie.avi','fps',20); 

axis_range=[-2 2 -2 2];
close all, figure
set(gcf,'Color',[179 199 255]/255,'position',[40 40 500 650])
x_L=[axis_range(1):0.001:axis_range(2)];
subplot(5,1,1), plot(x_L,2*exp(-(x_L/2).^2)), axis([axis_range(1:2) 0.7 2]),
xlabel('x (mm)'), ylabel('[L] (\muM)')

for t_i = 1 : STEPS
    
    
    subplot(5,1,[2:5]),hold off
    for bact_i=1:100
        bact_drew=[bact_xd(t_i,1:2,bact_i)+0.015*bact_xd(t_i,3:4,bact_i);...
                   bact_xd(t_i,1:2,bact_i)-0.015*bact_xd(t_i,3:4,bact_i)];
        plot(bact_drew(:,1),bact_drew(:,2),'LineWidth',1);%'Marker','.',
        hold on
    end
    axis equal;axis(axis_range)
    xlabel('x (mm)'),ylabel('y (mm)')
    s_inter=floor(t_i/2);
    s1=s_inter-floor(s_inter/10)*10;s_inter=floor(s_inter/10);
    s10=s_inter-floor(s_inter/6)*6;s_inter=floor(s_inter/6);
    m1=s_inter-floor(s_inter/10)*10;s_inter=floor(s_inter/10);
    m10=s_inter-floor(s_inter/6)*6;s_inter=floor(s_inter/6);
    timestr=char('00:00'+[m10 m1 0 s10 s1]);
    text(1.2,-1.8,timestr,'FontSize',20)    
    
    frame = getframe(gcf);
    aviobj = addframe(aviobj,frame);
end

aviobj = close(aviobj);

