%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%   This file is part of chemotaxis pathway designer                    % 
%                                                                       % 
%   Copyright (C) Junjie Luo     jjluo54@163.com                        % 
%                 Jun Wang.      wj-cn@163.com                          % 
%   All rights reserved.                                                % 
%                                                                       % 
%   $File: bacterium_parameter_test.m$     $Revision:  1$               %   
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function x_out = bacterium_parameter_test(Turn_1,Turn_2,Ampl,order,field_input,initial_point)

%Set model and ligand field
global model field
model='auto';
field=field_input;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%Set pathway parameter
global a;
global b;
switch order
    case 2
        a=[Turn_1*Turn_2,Turn_1+Turn_2];
        b=[0,-Ampl*(Turn_1+Turn_2)];
    case 4       
        a=[Turn_1^2*Turn_2^2,2*Turn_1*Turn_2*(Turn_1+Turn_2),(Turn_1+Turn_2)^2+2*(Turn_1*Turn_2),2*(Turn_1+Turn_2)];
        b=[0,0,-Ampl*(Turn_1+Turn_2)^2,0];
    otherwise
        error('No such order');
end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%Set total steps of simulation
global STEPS;
STEPS = 2000;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%Set the starting state
global x direction; 
x = initial_point;             %unit: mm  %Initial position of bacterium
theta=rand(1)*2*pi;
direction = [cos(theta), sin(theta)];   %Initial direction of bacterium
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%Set the state of motor
%Value:  0: CW   tumble
%        1: CCW  run
global state; 
state = 0;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%The state of motor is considered constant in a small time scale.
%Set the small time scale
global dt; 
dt = 0.5;                %Unit: s
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%Set the velocity of bacterium moving in medium
global v 
v = 0.02;                         %Unit: mm/s
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%Start at steady state.
y = steady_state(x, field, model);

theta = pi * rand(1) * 2;               
for step_i = 1 : STEPS
    if state                        % Run
        x = x + direction * v * dt;                     % Renew position
    else                            % Tumble
        theta0 = theta + sign(rand(1) - 0.5) * pi / 90 * exp(randn(1) * 0.5084 + 3.9358);
    	theta = theta0 - floor(theta0 / (pi * 2))* pi * 2;
        direction = [cos(theta), sin(theta)];           % Renew direction
    end;  
    
    %Calculate CheYp
    opt = odeset('abstol', 1e-6);
    [t_ode45, y_ode45] = ode15s(@ODE, [0, dt / 2, dt], y, opt);   
    y = y_ode45(end, :);
    
    state = motor(y(end), state, dt);   % Renew the state 
    
    x_out(step_i, :) = x;               % Record position of the bacterium  
    %CheYp_out(step_i) = y(end);         % Record CheYp
    
end

x_out=x_out(end-99:end,:);              % Output last 100 time points

%Plot
 %figure, plot(x_out(:, 1), x_out(:, 2)) % Trace of bacterium
 %figure, plot(x_out(:, 1))              % x-t curve
 %figure, plot(CheYp_out)                % [CheY-p]-t curve
