%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%   This file is part of chemotaxis pathway designer                    % 
%                                                                       % 
%   Copyright (C) Junjie Luo     jjluo54@163.com                        % 
%                 Jun Wang       wj-cn@163.com                          % 
%   All rights reserved.                                                % 
%                                                                       % 
%   $File: motor.m$     $Revision:  1$                         %   
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function s = motor(CheYp, state, dt)
% CheYp : The value of CheYp
% State : The state of the motor, CW or CCW
% dt    : The small time scale
% Return value : New state of the motor
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

if CheYp <= 0
	CheYp = eps;
end

Km = 3.1;
Hill = 10.3;
fm4 = 6.8;
pCW = 1 / ((Km / CheYp)^Hill + 1);                               %k120/(k120+k021)
f = fm4 * (CheYp / Km)^(Hill - 1) / ((CheYp / Km)^Hill + 1)^2;   %2/(1/k120+1/k021)
switch state
    case 0                                          % The state is CW
        p021 = f / pCW / 2 * dt;
        s = (rand() < p021);
    case 1                                          % The state is CCW
        p120 = f / (1 - pCW) / 2 * dt;
        s = (rand() > p120);
    otherwise
        error('Undefied motor state')
end
