%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%   This file is part of chemotaxis pathway designer                    % 
%                                                                       % 
%   Copyright (C) Junjie Luo     jjluo54@163.com                        % 
%                 Jun Wang       wj-cn@163.com                          % 
%   All rights reserved.                                                % 
%                                                                       % 
%   $File: pathway.m$     $Revision:  1$                         %   
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function dy = pathway(L, y, model)
% L : The concentration value of ligand
% y : A list of concentration of molecules in chemotaxis pathway
% model : The label of pathway model
% Return value : The differential coefficient of y
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

switch model
    case 'auto_1' %R=L/(L+1), Y(s)/R(s)=b/(s+a)
        global a b
        dy=-a*y+b*L/(L+1);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    case 'auto_2' %R=L/(L+1), Y(s)/R(s)=b(2)*s+b(1)/(s^2+a(2)*s+a(1))
        global a b
        dy=[[0;1],-a']*y+b'*L/(L+1);        
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    case 'auto' %R=L/(L+1), Y(s)/R(s)=b(2)*s+b(1)/(s^2+a(2)*s+a(1))
        global a b y_delta_auto
        n_auto=size(a,2);
        dy=[[zeros(1,n_auto-1);eye(n_auto-1)],-a']*(y-[zeros(n_auto-1,1);y_delta_auto])+b'*L/(L+1);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    case 'design-' %R=L/(L+1),
        global k1 k2 k3 dv Y
        
        dy=[k1*L/(L+1)-dv*y(1);...
	    k2*L/(L+1)*(Y-y(2))-k3*y(1)*y(2)];
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    case 'design+' %R=L/(L+1),
        global k1 k2 k3 dv Y
        
        dy=[k1*L/(L+1)-dv*y(1);...
	    k3*y(1)*(Y-y(2))-k2*L/(L+1)*y(2)];
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    case 'psudo' %R=L/(L+1),
        global k1 k2 k3 dv
        global Y
        
        dy=[k1*L/(L+1)-dv*y(1);...
	    k2*(Y-y(2))-k3*y(1)*y(2)];
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    case 'Ribo_Lac'
        
n_z=150;r_z=6e-3;
n_i=5;r_i=6e-3;
tau_mRNA=120;

r_translate=1e-4;
tau_CheZ=600;
tau_LacI=600;

K_LacI=0.0471;hill_LacI=2;
K_L=1;

ky=80;
P=5.3/2;
Y0=4.5;
kry=30;

R_Ligand=1/(K_L/L+1);
global Lin
if Lin
    Y0=3.5487;
    
    R_LacI=1/(1+(y(4)/K_LacI)^hill_LacI);
dy=[-log(2)/tau_mRNA*y(1)+r_z*n_z*R_LacI;...		%CheZ mRNA
    -log(2)/tau_mRNA*y(2)+r_i*n_i*R_LacI;...		%LacI mRNA
    -log(2)/tau_CheZ*y(3)+r_translate*y(1)*R_Ligand;...	%CheZ protein
    -log(2)/tau_LacI*y(4)+r_translate*y(2)*R_Ligand;...	%LacI Protein
    ky*P*(Y0-y(5))-kry*y(3)*y(5)];				%CheY-p
else
    Y0=5.5578;
    
dy=[-log(2)/tau_mRNA*y(1)+r_z*n_z;...		%CheZ mRNA
    -log(2)/tau_CheZ*y(2)+r_translate*y(1)*R_Ligand;...	%CheZ protein
    ky*P*(Y0-y(3))-kry*y(2)*y(3)];				%CheY-p
end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    case 'Cd'
global n_z r_z n_i r_i tau_mRNA                
global r_translate tau_CheZ tau_CI
global K_L
global ky P Y0 kry
global OR_para

R_Ligand=1/(K_L/L+1);
CI_2=y(2)/2+(0.018-sqrt(2*4*y(2)*0.018+0.018^2))/8;
fr_solve=OR_para.K.*(CI_2.^OR_para.i_s).*(0.03.^OR_para.k_s);
R_CI=(0.011*sum(fr_solve([12 15],:),1)+0.001*sum(fr_solve([5 10 13],:),1))./sum(fr_solve,1);

dy=[-log(2)/tau_mRNA*y(1)+r_i*n_i*R_Ligand;...		%CI mRNA
    -log(2)/tau_CI*y(2)+r_translate*y(1);...        %CI Protein
    -log(2)/tau_mRNA*y(3)+n_z*R_CI;...        		%CheZ mRNA
    -log(2)/tau_CheZ*y(4)+r_translate*y(3);...      %CheZ protein
    ky*P*(Y0-y(5))-kry*y(4)*y(5)];              	%CheY-p

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    case 'R2'
        global Rs0 Rw0 Ks_w
        global TRs KRs TRw KRw Dm 
        global Kdi Tp Dp
        global ky P Y0 kry

        dy=[TRw/((KRw/Rw0)*(1+1/L)+1)-Dm*y(1);...%CheZ+ mRNA
            TRs/((KRs/Rs0)*(1+1/(Ks_w*L))+1)-Dm*y(2);...%CheZ- mRNA
            Tp*(y(1)+y(2)+Kdi-sqrt((y(1)+y(2)+Kdi)^2-4*y(1)*y(2)))/2-Dp*y(3);... %CheZ protein
            ky*P*(Y0-y(4))-kry*y(3)*y(4)];%CheY-p
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    case 'PLoS'
        global gamma_net L_para
k_net=(gamma_net+abs(gamma_net))/2;

dy=k_net*y-diag(y)*abs(gamma_net)*y+(1-y).*(diag(k_net)-y.*abs(diag(gamma_net)));
dy(1)=dy(1)+((L_para+abs(L_para))/2-abs(L_para)*y(1))*L;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    case 'WT'
        % parameter setting
%%mu mol(e-6mol), s
%global B0 Y0 Z R T0
B0=1.7;
Y0=20;
Z=40;
R=0.3;
T0=8;
%global kc1 kc2 kc3 kc4 KR
kc1=0.17;
kc2=0.1*kc1;
kc3=30*kc1;
kc4=30*kc2;
KR=1.7;
%global kr1 kr2 kr3 kr4
kr1=0.4;
kr2=0.03;
kr3=kr1;
kr4=kr2;
%global k5 kr5
k5=70;
kr5=70;
%global k8 k9 k10 k11 k12 k13
k8=15;
k9=3*k8;
k10=3.2*k8;
k11=0;
k12=1.1*k8;
k13=0.72*k10;
%global ky kry kb krb
kb=0.8;
ky=30;
krb=0.35;
kry=0.5;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%dT2/dt
dy(1,1)=-L*k5*y(1)+kr5*y(4)...
    -k8*y(1)+ ky*y(7)*(Y0-y(14))+kb*y(7)*(B0-y(13))...
    -R*kc1*y(1)/(KR+y(1)) +y(13)*kr1*y(2);
%dT3/dt
dy(2,1)=-L*k5*y(2)+kr5*y(5)...
    -k9*y(2)+ ky*y(8)*(Y0-y(14))+kb*y(8)*(B0-y(13))...
    -R*kc2*y(2)/(KR+y(2))+R*kc1*y(1)/(KR+y(1)) -y(13)*kr1*y(2)+ y(13)*kr2*y(3);
%dT4/dt
dy(3,1)=-L*k5*y(3)+kr5*y(6)...
    -k10*y(3)+ ky*y(9)*(Y0-y(14))+kb*y(9)*(B0-y(13))...
    +R*kc2*y(2)/(KR+y(2))-y(13)*kr2*y(3);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%dLT2/dt
dy(4,1)=+L*k5*y(1)-kr5*y(4)...
    -k11*y(4)+ ky*y(10)*(Y0-y(14))+kb*y(10)*(B0-y(13))...
    -R*kc3*y(4)/(KR+y(4)) +y(13)*kr3*y(5);
%dLT3/dt
dy(5,1)=+L*k5*y(2)-kr5*y(5)...
    -k12*y(5)+ ky*y(11)*(Y0-y(14))+kb*y(11)*(B0-y(13))...
    -R*kc4*y(5)/(KR+y(5))+R*kc3*y(4)/(KR+y(4))-y(13)*kr3*y(5)+ y(13)*kr4*y(6);
%dLT4/dt
dy(6,1)=+L*k5*y(3)-kr5*y(6)...
    -k13*y(6)+ ky*y(12)*(Y0-y(14))+kb*y(12)*(B0-y(13))...
    +R*kc4*y(5)/(KR+y(5))-y(13)*kr4*y(6);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%dT2p/dt
dy(7,1)=-L*k5*y(7)+kr5*y(10)...
    +k8*y(1)- ky*y(7)*(Y0-y(14))-kb*y(7)*(B0-y(13))...
    -R*kc1*y(7)/(KR+y(7)) +y(13)*kr1*y(8);
%dT3p/dt
dy(8,1)=-L*k5*y(8)+kr5*y(11)...
    +k9*y(2)-ky*y(8)*(Y0-y(14))-kb*y(8)*(B0-y(13))...
    - R*kc2*y(8)/(KR+y(8))+R*kc1*y(7)/(KR+y(7)) -y(13)*kr1*y(8)+ y(13)*kr2*y(9);
%dT4p/dt
dy(9,1)=-L*k5*y(9)+kr5*y(12)...
    +k10*y(3) -ky*y(9)*(Y0-y(14))-kb*y(9)*(B0-y(13))...
    +R*kc2*y(8)/(KR+y(8))-y(13)*kr2*y(9);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%dLT2p/dt
dy(10,1)=+L*k5*y(7)-kr5*y(10)...
    +k11*y(4) -ky*y(10)*(Y0-y(14))-kb*y(10)*(B0-y(13))...
    -R*kc3*y(10)/(KR+y(10)) +y(13)*kr3*y(11);
%dLT3p/dt
dy(11,1)=+L*k5*y(8)-kr5*y(11)...
    +k12*y(5)-ky*y(11)*(Y0-y(14))-kb*y(11)*(B0-y(13))...
    -R*kc4*y(11)/(KR+y(11))+R*kc3*y(10)/(KR+y(10))-y(13)*kr3*y(11)+ y(13)*kr4*y(12);
%dLT4p/dt
dy(12,1)=+L*k5*y(9)-kr5*y(12)...
    +k13*y(6) - ky*y(12)*(Y0-y(14))-kb*y(12)*(B0-y(13))...
    +R*kc4*y(11)/(KR+y(11))-y(13)*kr4*y(12);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
P=y(7)+y(10)+y(8)+y(11)+y(9)+y(12);
%dBp/dt
dy(13,1)=kb*P*(B0-y(13))-krb*y(13);
%dYp/dt
dy(14,1)=ky*P*(Y0-y(14))-kry*Z*y(14);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    otherwise
        error('Undefied model')
end