%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%   This file is part of chemotaxis pathway designer                    % 
%                                                                       % 
%   Copyright (C) Junjie Luo     jjluo54@163.com                        % 
%                 Jun Wang       wj-cn@163.com                          % 
%   All rights reserved.                                                % 
%                                                                       % 
%   $File: steady_state.m$     $Revision:  1$                         %   
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function y_t0 = steady_state(x, field, model)
% x : The position of the bacterium
% field : The kind of concentration field
% model : The label of pathway model
% Return value : A list of concentration of molecules in chemotaxis pathway
%                at steady state
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

switch model
    case 'auto'
        global a b
        n_auto = size(a, 2);
        L_ss=L(x,field);R=L_ss/(L_ss+1);
        y_t0=-[[zeros(1,n_auto-1);eye(n_auto-1)],-a']\b'*R;
        global y_delta_auto
        y_delta_auto=2.71-y_t0(end);
        y_t0(end)=2.71;
    case 'design-'
        global k1 k2 k3 dv Y
        k1=0.03;k2=20;k3=20;
        dv=0.03;
        Y=2.71*(1+k3*k1/(k2*dv));
	
        y_t0=[k1/(dv*(1+1/L(x,field)));2.71]
    case 'design+' %R=L/(L+1),
        global k1 k2 k3 dv Y
        k1=0.03;k2=20;k3=20;
        dv=0.03;
        Y=2.71*(1+k2*dv/(k3*k1));
        
        y_t0=[k1/(dv*(1+1/L(x,field)));2.71]
    case 'psudo' %R=L/(L+1),    
        R=L(x,field)/(L(x,field)+1);
        global k1 k2 k3 dv
        k1=0.03;k2=20*R;k3=20;
        dv=0.03;
        global Y
        Y=2.71*(1+k3*k1/(dv*k2*(1+1/L(x,field))));
        y_t0=[k1/(dv*(1+1/L(x,field)));2.71]
    case 'Ribo_Lac'
        global Lin
        if Lin
            [y_t0,residual]=fsolve(@(y)pathway(L(x,field),y,model),[150,5,7.5,0.2,2.194])
        else
            [y_t0,residual]=fsolve(@(y)pathway(L(x,field),y,model),[155.8111,7.4263,2.1942])
        end
    case 'Cd'
global n_z r_z n_i r_i tau_mRNA                
n_z=300;r_z=6e-3;
n_i=200;r_i=6e-3;
tau_mRNA=120;
global r_translate tau_CheZ tau_CI
r_translate=1e-4;
tau_CheZ=300;
tau_CI=200;
global K_L
K_L=1;
global ky P Y0 kry
ky=80;
P=2.5;
Y0=5;
kry=30;
global OR_para
load('OR_p')

R_Ligand=1/(K_L/L(x,field)+1);
y_t0(1)=r_i*n_i*R_Ligand*tau_mRNA/log(2);...		%CI mRNA
y_t0(2)=r_translate*y_t0(1)*tau_CI/log(2);...          %CI Protein
    
CI_2=y_t0(2)/2+(0.018-sqrt(2*4*y_t0(2)*0.018+0.018^2))/8;
fr_solve=OR_para.K.*(CI_2.^OR_para.i_s).*(0.03.^OR_para.k_s);
R_CI=(0.011*sum(fr_solve([12 15],:),1)+0.001*sum(fr_solve([5 10 13],:),1))./sum(fr_solve,1);

y_t0(3)=n_z*R_CI*tau_mRNA/log(2);...        		%CheZ mRNA
y_t0(4)=r_translate*y_t0(3)*tau_CheZ/log(2);...        %CheZ protein
y_t0(5)=ky*P*Y0/(ky*P+kry*y_t0(4));                 	%CheY-p

    case 'R2'
        global Rs0 Rw0 Ks_w
            Rs0=10;Rw0=Rs0;
            Ks_w=1e-3;
        global TRs KRs TRw KRw Dm 
            TRs=300*6e-3;KRs=1e-1;
            TRw=300*3e-3;KRw=10;
            Dm=log(2)/120;
        global Kdi Tp Dp
            Kdi=20;
            Tp=5e-4;
            Dp=log(2)/600;
        global ky P Y0 kry
            ky=80;P=2.5;
            Y0=5;kry=30;

        y_t0(1)=TRw/((KRw/Rw0)*(1+1/L(x,field))+1)/Dm;%CheZ+ mRNA
        y_t0(2)=TRs/((KRs/Rs0)*(1+1/(Ks_w*L(x,field)))+1)/Dm;%CheZ- mRNA
        y_t0(3)=Tp*(y_t0(1)+y_t0(2)+Kdi-sqrt((y_t0(1)+y_t0(2)+Kdi)^2-4*y_t0(1)*y_t0(2)))/2/Dp;     %CheZ protein
        y_t0(4)=ky*P*Y0/(ky*P+kry*y_t0(3));      %CheY-p

    case 'PLoS'    
        global protein
        y_t0=zeros(protein,1);
    case 'WT'
        y_t0=fsolve(@SS_equation_WT,[ones(1,12),0,10]);
    otherwise
        error('Undefied model')
end